# pyx2pxd


Simple library to automatically to auto generate pxd files from pyx by extracting function and class signatures.

---


## Installation

You can install `pyx2pxd` via [pip]:

```shell
pip install pyx2pxd
```

## License

Distributed under the terms of the [GNU GPL v2.0] license,
"pyx2pxd" is free and open source software

## Issues

If you encounter any problems, please [file an issue] along with a detailed description.

[file an issue]: https://github.com/HenriquesLab/NanoPyx/issues
[pip]: https://pypi.org/project/pip/
[pypi]: https://pypi.org/
